/* Name of package */
#undef PACKAGE

/* Version number of package */
#undef VERSION

@BOTTOM@

#include "cxxconfig.h"
